@@ -127,12 +127,15 @@ CORRESPONDANCE: a.dickson2@lancaster.ac.uk
     # Build GP model 
     y_mean = y_train.mean()
     y_std = y_train.std()
-    # Standardise to unit variance
+    # Standardise to unit variance and zero mean
     y_train_std = (y_train - y_mean) / y_std
 
+    # standardise Gaussian noise
+    noise_train_std = noise_train / (y_std ** 2)
+
     # Likelihood (noise) model
     likelihood = gpytorch.likelihoods.FixedNoiseGaussianLikelihood(
-        noise=noise_train, learn_additional_noise=False
+        noise=noise_train_std, learn_additional_noise=False
     )
     model = ExactGPModel(X_train, y_train_std, likelihood)
     mll = gpytorch.mlls.ExactMarginalLogLikelihood(likelihood, model)
@@ -157,12 +160,14 @@ CORRESPONDANCE: a.dickson2@lancaster.ac.uk
         save_checkpoint(X_train, y_train, noise_train, it, imse, stage="iter")
         
         # Grab predicted variance at all probe points
-        _, var_pred = query_model(model=model, likelihood=None, probe_pts=probe, y_std=y_std, y_mean=y_mean)
+        _, var_pred = query_model(model=model, likelihood=likelihood, probe_pts=probe, y_std=y_std, y_mean=y_mean)
         idx = torch.argmax(var_pred).item()
         # Find point with maximum variance
         new_pts = probe[idx].unsqueeze(0)
 
-        pred_mean, pred_var = query_model(model=model, likelihood=None, probe_pts=new_pts, y_std=y_std, y_mean=y_mean)
+
+        # Predict TDE of next point
+        pred_mean, pred_var = query_model(model=model, likelihood=likelihood, probe_pts=new_pts, y_std=y_std, y_mean=y_mean)
      
         
         # Efficient TDE evaluation by inclusion of guess start energy two standard deviations below predicted TDE, if lower than 1 eV
@@ -189,13 +194,15 @@ CORRESPONDANCE: a.dickson2@lancaster.ac.uk
         X_train = torch.cat([X_train, new_pts])
         y_train = torch.cat([y_train, torch.tensor(new_y)])
         noise_train = torch.cat([noise_train, torch.tensor(new_n)])
-        likelihood.noise = noise_train.clone()
         # Renormalise data 
         y_mean = y_train.mean()
         y_std = y_train.std()
         y_train_std = (y_train - y_mean) / y_std
+        noise_train_std = noise_train / (y_std ** 2)
 
         # Retrain model
+        # Update likelihood noise
+        likelihood.noise = noise_train_std.clone()
         model.set_train_data(X_train, y_train_std, strict=False)
         optimise_model(model, X_train, y_train_std, likelihood, mll)
         # Create arrays for evaluations at probe points
